*list-headlines.ps1*
================

This PowerShell script lists the latest RSS feed news.

Parameters
----------
```powershell
PS> ./list-headlines.ps1 [[-RSS_URL] <String>] [[-maxCount] <Int32>] [<CommonParameters>]

-RSS_URL <String>
    Specifies the URL to the RSS feed
    
    Required?                    false
    Position?                    1
    Default value                https://yahoo.com/news/rss/world
    Accept pipeline input?       false
    Accept wildcard characters?  false

-maxCount <Int32>
    Specifies the number of news to list
    
    Required?                    false
    Position?                    2
    Default value                20
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-headlines.ps1
❇️ Niger coup: Ecowas deadline sparks anxiety in northern Nigeria
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists the latest headlines
.DESCRIPTION
	This PowerShell script lists the latest RSS feed news.
.PARAMETER RSS_URL
	Specifies the URL to the RSS feed
.PARAMETER maxCount
	Specifies the number of news to list
.EXAMPLE
	PS> ./list-headlines.ps1
	❇️ Niger coup: Ecowas deadline sparks anxiety in northern Nigeria
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$RSS_URL = "https://yahoo.com/news/rss/world", [int]$maxCount = 20)

try {
	[xml]$content = (Invoke-WebRequest -uri $RSS_URL -useBasicParsing).Content
	[int]$count = 0
	foreach ($item in $content.rss.channel.item) {
		"❇️ $($item.title)"
		$count++
		if ($count -eq $maxCount) { break }
	}
        $source = $Content.rss.channel.title
        $date = $Content.rss.channel.pubDate
	"   (by $source as of $date)"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of list-headlines.ps1 as of 10/19/2023 08:11:39)*
