*what-is.ps1*
================

This PowerShell script queries the meaning of the given abbreviation and prints it.

Parameters
----------
```powershell
PS> ./what-is.ps1 [[-abbr] <String>] [<CommonParameters>]

-abbr <String>
    Specifies the abbreviation to query
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./what-is VTOL
💡 VTOL in aviation refers to Vertical Take-Off and Landing

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Explains an abbreviation
.DESCRIPTION
	This PowerShell script queries the meaning of the given abbreviation and prints it.
.PARAMETER abbr
	Specifies the abbreviation to query
.EXAMPLE
	PS> ./what-is VTOL
	💡 VTOL in aviation refers to Vertical Take-Off and Landing
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$abbr = "")

try {
	if ($abbr -eq "" ) { $abbr = Read-Host "Enter the abbreviation to query" }
	$files = (Get-ChildItem "$PSScriptRoot/../Data/Abbr/*.csv")
	$basename = ""
	foreach($file in $files) {
		$table = Import-CSV "$file"
		foreach($row in $table) {
			if ($row.ABBR -ne $abbr) { continue }
			$basename = (Get-Item "$file").Basename -Replace "_"," "
			"💡 $($row.ABBR) in $basename refers to $($row.MEANING)"
		}
	}
	if ($basename -eq "") { "🤷‍ Sorry, no entry '$abbr' in my database (located at .../Data/Abbr/)." }
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of what-is.ps1 as of 10/19/2023 08:11:43)*
